""" Contains all the data models used in inputs/outputs """

from .address import Address
from .affiliation import Affiliation
from .article import Article
from .article_citations import ArticleCitations
from .author import Author
from .citation import Citation
from .citation_ids import CitationIds
from .citation_scopes import CitationScopes
from .citation_titles import CitationTitles
from .pers_name import PersName
from .process_form import ProcessForm
from .ref import Ref
from .section import Section
from .text_with_refs import TextWithRefs
from .uploaded_file import UploadedFile
